==> spread-5.0.0.54-py3-none-any.whl: spread_core/mqtt/__init__.py <==
from .base import Topic
from spread_core.errors.project_errors import TopicError, AddressError
from . import bus, const, jocket, tros3, spread, project
from .classifier import LINEAR_CURVE, LOGARITHMIC_CURVE
from .classifier import classifier


def of(topic):
    arr = topic.split('/')
    try:
        if arr[0] == jocket.topic.JocketTopic.protocol:
            if arr[1] == jocket.topic.TopicReply.topic_type:
                return jocket.topic.TopicReply(arr[2], *arr[3:])
            elif arr[1] == jocket.topic.TopicState.topic_type:
                return jocket.topic.TopicState(arr[2], jocket.address.EntityAddress.deserialize(*arr[3:]))
            elif arr[1] == jocket.topic.TopicCommand.topic_type:
                return jocket.topic.TopicCommand(arr[2], arr[3], jocket.address.EntityAddress.deserialize(*arr[4:]))
        elif arr[0] == tros3.topic.TROS3Topic.protocol:
            if arr[1] == tros3.topic.TopicCommandTros3.topic_type:
                return tros3.topic.TopicCommandTros3(arr[2], jocket.address.EngineryAddress(*arr[-3:]))
            elif arr[1] == tros3.topic.TopicStateTros3.topic_type:
                return tros3.topic.TopicStateTros3(arr[2], jocket.address.EngineryAddress(*arr[-3:]))
        elif arr[0] == spread.topic.SpreadTopic.protocol:
            if arr[1] == spread.topic.Reply.action:
                return spread.topic.Reply(*arr[2:])
            for scl in spread.topic.SpreadTopic.__subclasses__():
                if issubclass(scl, spread.topic.SpreadTopic) and scl.action == arr[1]:
                    return scl(spread.address.of('/'.join(arr[2:])))
        elif arr[0] == bus.TopicBus.protocol and len(arr) > 2:
            return bus.TopicBus(arr[1], '/'.join(arr[3:]))
        elif arr[0] == project.TopicProject.protocol:
            if arr[2] == project.Local.protocol:
                return project.Local.of(topic)
            elif arr[2] == project.ProjectHash.HASH:
                return project.ProjectHash(arr[1])
            elif len(arr) > 2:
                return project.TopicProject(arr[1], arr[3:])
    except AddressError as ex:
        raise TopicError("Couldn't parse address of " + topic)
    else:
        raise TopicError(f'Unsupported topic "{topic}"')

==> spread-5.1.0.48-py3-none-any.whl: spread_core/mqtt/__init__.py <==
from .base import Topic
from spread_core.errors.project_errors import TopicError, AddressError
from . import bus, const, jocket, tros3, spread, project, local
from .classifier import LINEAR_CURVE, LOGARITHMIC_CURVE
from .classifier import classifier


def of(topic):
    arr = topic.split('/')
    try:
        if arr[0] == jocket.topic.JocketTopic.protocol:
            if arr[1] == jocket.topic.TopicReply.topic_type:
                return jocket.topic.TopicReply(arr[2], *arr[3:])
            elif arr[1] == jocket.topic.TopicState.topic_type:
                return jocket.topic.TopicState(arr[2], jocket.address.EntityAddress.deserialize(*arr[3:]))
            elif arr[1] == jocket.topic.TopicCommand.topic_type:
                return jocket.topic.TopicCommand(arr[2], arr[3], jocket.address.EntityAddress.deserialize(*arr[4:]))
        elif arr[0] == tros3.topic.TROS3Topic.protocol:
            if arr[1] == tros3.topic.TopicCommandTros3.topic_type:
                return tros3.topic.TopicCommandTros3(arr[2], jocket.address.EngineryAddress(*arr[-3:]))
            elif arr[1] == tros3.topic.TopicStateTros3.topic_type:
                return tros3.topic.TopicStateTros3(arr[2], jocket.address.EngineryAddress(*arr[-3:]))
        elif arr[0] == spread.topic.SpreadTopic.protocol:
            if arr[1] == spread.topic.Reply.action:
                return spread.topic.Reply(*arr[2:])
            for scl in spread.topic.SpreadTopic.__subclasses__():
                if issubclass(scl, spread.topic.SpreadTopic) and scl.action == arr[1]:
                    return scl(spread.address.of('/'.join(arr[2:])))
        elif arr[0] == bus.TopicBus.protocol and len(arr) > 2:
            return bus.TopicBus(arr[1], '/'.join(arr[3:]))
        elif arr[0] == project.TopicProject.protocol:
            if arr[2] == local.Local.protocol:
                return local.Local.of(topic)
            elif arr[2] == project.ProjectHash.HASH:
                return project.ProjectHash(arr[1])
            elif len(arr) > 2:
                return project.TopicProject(arr[1], arr[3])
    except AddressError:
        raise TopicError("Couldn't parse address of " + topic)
    else:
        raise TopicError(f'Unsupported topic "{topic}"')
